@@ -1,10 +1,7 @@
 #!/usr/bin/env python3
 import typing
-import pty
-import select
-from sys import stdin, stdout
 from subprocess import Popen, CalledProcessError
-from os import environ, read, write, setsid
+from os import environ
 
 
 class CommonHarnessLib:
@@ -142,25 +139,9 @@ class CommonHarnessLib:
             command,  # Command to run in array
             keep_alive=True,  # Whether to keep python open until complete
             throw_errors=False,  # Raise an error if the program errors
-            spawn_pty=False  # Spawn program in pseudo-tty, if program needs it
          ):
-        # Spawn in pty
-        if spawn_pty:
-            master, slave = pty.openpty()
-            popen = Popen(command, preexec_fn=setsid, stdin=slave, stdout=slave, stderr=slave, universal_newlines=True)  # NOQA
-            while popen.poll() is None:
-                r, w, e = select.select([stdin, master], [], [], 0)
-                if stdin in r:
-                    d = read(stdin.fileno(), 10240)
-                    write(master, d)
-                elif master in r:
-                    o = read(master, 10240)
-                    if o:
-                        write(stdout.fileno(), o)
-        # Run as regular popen
-        else:
-            popen = Popen(command, universal_newlines=True)
-            if keep_alive:
-                return_code = popen.wait()
-                if return_code and throw_errors:
-                    raise CalledProcessError(return_code, command)
+        popen = Popen(command, universal_newlines=True)
+        if keep_alive:
+            return_code = popen.wait()
+            if return_code and throw_errors:
+                raise CalledProcessError(return_code, command)
